# Awesome Godot [![Awesome](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)](https://github.com/sindresorhus/awesome)

A curated list of [free/libre](https://gnu.org/philosophy/free-sw.html) games, plugins, add-ons and scripts for [Godot](http://godotengine.org).

For installation instructions, read [INSTALL.md](https://github.com/Calinou/awesome-godot/blob/master/INSTALL.md).

## Games

*Games that use Godot.*

### 2D

- [Blipshift](https://github.com/wardsky/blipshift) - Simple top-down moving platforms game.
- [BlockPop](https://github.com/vnen/blockpop) - A simple Breakout clone.
- [Bombs](https://github.com/randyyaj/Bombs) - Simple mobile game. You need to touch bombs to diffuse them.
- [DynaDungeons](https://github.com/akien-mga/dynadungeons) - Bomberman clone in a fantasy universe.
- [Kraken-Rampage](https://github.com/randyyaj/Kraken-Rampage) - Ludum Dare 33 entry made in 48 hours.
- [Libre Pinball](https://github.com/Calinou/libre-pinball) - A pinball game.
- [Minilens](http://kobuge-games.github.io/minilens/) - Free puzzle platform game.
- [Ninja-Training
](https://github.com/KOBUGE-Games/Ninja-Training) - Small running game done as 1 hour challenge.
- [No hope](https://github.com/sergicollado/no_hope_LD33) - Ludum Dare 33 entry made in 48 hours.
- [Planet Rider](https://github.com/FEDE0D/Planet-Rider) - 2D physics parkour game in an alien environment.
- [Ringed](https://github.com/KOBUGE-Games/ringed) - Top-down shooter with extensive usage of light effects.
- [Tanks of Freedom](https://github.com/w84death/Tanks-of-Freedom) - Free turn-based isometric strategy game.

### 3D

Nothing for now.

## Demos

*Demos to learn GDScript, its concepts, and various game features.*

- [FPS Test](https://github.com/Calinou/fps-test) - A singleplayer FPS test. Physics work, but there are no enemies and no proper shooting.
- [HTTP Server](https://github.com/KOBUGE-Games/godot-httpd) - A HTTP 1.0 file server.
- [Pathfinding 2d](https://github.com/FEDE0D/godot-pathfinding2d-demo) - A demo project demonstrating pathfinding using a tilemap.
- [TCP Networked physics](https://github.com/jrimclean/godot-snapshot-interpolation-demo) - Lets you connect to a server and view networked physics.
- [UDP State synchronization](https://github.com/jrimclean/godot-state-sync-demo) - A more efficient networking demo than the previous one.

## Themes

*Themes for your Godot games or user interface.*

- [Iso Dark Theme](https://github.com/GalanCM/Iso-Themes) - A clean, modern dark theme.

## Modules

*Stuff integrated into Godot core (C++).*

- [Gdnet](https://github.com/jrimclean/gdnet) - An ENet wrapper for Godot.
- [WaterSplash 2D node](https://github.com/laverneth/WaterSplash)
- [Head tracking using OpenCV](https://github.com/antarktikali/godot-opencv-gpu-perspective)
- [RawPacker](https://github.com/jrimclean/rawpacker) - Simple binary packing/unpacking for RawArray.

## Plugins and scripts

*Scripts that let you do new stuff, or enhance Godot functionality.*

- [Add Primitives](https://github.com/TheHX/add_primitives) - Add cylinders, spheres, cubes easily.
- [Color Picker](https://github.com/TeddyDD/godot-ColorPicker) - A color picker integrated into Godot.
- [Create Tileset](https://github.com/vinod8990/godot_plugins) - Plugin to generate Godot tilesets based on atlas images
- [Example Model Importer](https://github.com/TheHX/godot_examples) - A script that imports models with inverted normals (proof of concept).
- [GodotNotificationCenter](https://github.com/didier-v/GodotNotificationCenter) - A notification center for Godot.
- [Grass Plugin](https://github.com/marcosbitetti/grass_plugin_4_godot) - A plugin to handle huge amount of grass, foliages and other vegetations
- [GUT](https://bitbucket.org/bitwes/gut/overview) - Utility for writing unit tests in GDScript.
- [Heightmap](https://gist.github.com/TheHX/94a83dea1a0f932d5805) - Make an heightmap into terrain.
- [Input states](http://pastebin.com/LuSg4wY2) - Input states for Godot.
- [OpenClipArt Store](https://github.com/vinod8990/godot_plugins/tree/master/OpenClipArt_Store) - Lets you integrate OpenClipArt assets easily, with a browser.
- [Polygon Merge](https://github.com/ScyDev/Godot-Scripts) - Merge polygons.
- [Resolution Switcher](https://github.com/vinod8990/godot_plugins) - Switch resolutions easily, for testing.
- [Simplex 2D/3D](https://github.com/OvermindDL1/Godot-Helpers) - Simplex deterministic noise functions.
- [SUTjoystick](https://gitlab.com/shine-upon-thee/joystick) - Easy gamepad support for GNU/Linux and Windows.
- [Tiled importer](https://github.com/MrGreenTea/GodotTiledImporter) - Import maps from [Tiled](http://mapeditor.org).
- [Tileset Builder](https://gist.github.com/Calinou/27e979ab0a35500c3381) - Build tilesets.

## GDScript syntax highlighting

*Add-ons for text editors that add syntax highlighting to GDscript.*

- [Atom](https://github.com/jlopezcur/language-gdscript) - Not present on atom.io, install it manually.
- [Geany](https://github.com/haimat/GDScript-Geany)
- [Gedit](https://github.com/haimat/GDScript-gedit)
- [Sublime Text](https://github.com/beefsack/GDScript-sublime)
- [Vim](https://github.com/quabug/vim-gdscript)

## Other

*Other stuff.*

- [godot.sh](https://github.com/adolson/godot-stuff/blob/master/godot.sh) - Script that automatically downloads and launches latest version of Godot, or compiles and launches git master branch.
- [godot-wrapper](https://github.com/nsrosenqvist/godot-wrapper.git) - Script that helps Debian and Ubuntu users install and use Godot.
- [replicate-file.sh](https://github.com/adolson/godot-stuff/blob/master/replicate-file.sh) - Script to update copies of a file with one master file.
- [strip-to-frames.pl](https://github.com/adolson/godot-stuff/blob/master/strip-to-frames.pl) - Perl script to split a grid spritesheet image into numbered individual frame files.
- [update-git.sh](https://gist.github.com/Calinou/93938dc92484bc5e89f0) - Updates all Git repositories contained in a directory.
